from enum import Enum


class EnumUserAuth(Enum):
    local = "local"
    google = "google"
    github = "github"
    slack = "slack"
    facebook = "facebook"
    twitter = "twitter"
    linkedin = "linkedin"
